@@ -239,7 +239,7 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
         :return: converted object in public format.
         """
         if value is None: return None
-        if value.get('_id'):
+        if '_id' in value.keys():
             value['id'] = value['_id']
             value.pop('_id', None)
 
@@ -258,7 +258,7 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
 
         value = PropertyReflector.get_properties(value)
 
-        if value.get('id'):
+        if 'id' in value.keys():
             value['_id'] = value.get('id') or value.get('_id')
             value.pop('id', None)
         return value
@@ -401,7 +401,7 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
 
         :param filter: (optional) a filter function to filter items.
         """
-        result = self._collection.delete_many(filter)
+        result = self._collection.delete_many(filter or {})
         count = 0 if result is None else result.deleted_count
         self._logger.trace(correlation_id, "Deleted %d items from %s", count, self._collection_name)
 
@@ -416,13 +416,13 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
 
         :return: a random item.
         """
-        count = self._collection.count_documents(filter)
+        count = self._collection.count_documents(filter or {})
 
         pos = random.randint(0, count)
 
         statement = self._collection.find(filter).skip(pos if pos > 0 else 0).limit(1)
-        for item in statement:
 
+        for item in statement:
             if item is None:
                 self._logger.trace(correlation_id, "Random item wasn't found from %s", self._collection_name)
             else:
@@ -454,17 +454,16 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
         skip = paging.get_skip(-1)
         take = paging.get_take(self._max_page_size)
         paging_enabled = paging.total
+        filter = filter or {}
 
         # Configure statement
-        statement = self._collection.find(filter)
+        statement = self._collection.find(filter, projection=select or {})
 
         if skip >= 0:
             statement = statement.skip(skip)
         statement = statement.limit(take)
         if sort is not None:
             statement = statement.sort(sort)
-        if select is not None:
-            statement = statement.select(select)
 
         # Retrive page items
         items = []
@@ -501,12 +500,11 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
         :return: a data list of results by filter.
         """
         # Configure statement
-        statement = self._collection.find(filter)
+        filter = filter or {}
+        statement = self._collection.find(filter, projection=select or {})
 
         if sort is not None:
             statement = statement.sort(sort)
-        if select is not None:
-            statement = statement.select(select)
 
         # Retrive page items
         items = []
@@ -530,6 +528,7 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
         :param filter: (optional) a filter JSON object
         :return: a number of filtered items.
         """
+        filter = filter or {}
         count = self._collection.count_documents(filter)
 
         if count is not None:
